@@ -63,7 +63,7 @@ _plotly_scene = dict(
     aspectmode="data",
 )
 _plotly_bz_style = {"line": {"color": "black", "width": 3}}
-_plotly_sym_pt_style = {"marker": {"size": 5, "color": "black"}}
+_plotly_sym_pt_style = {"marker": {"size": 6, "color": "black"}}
 _plotly_sym_label_style = dict(
     xshift=15, yshift=15, showarrow=False, font={"size": 20, "color": "black"}
 )
@@ -209,6 +209,7 @@ class FermiSurfacePlotter:
         hide_surface: bool = False,
         hide_labels: bool = False,
         hide_cell: bool = False,
+        plot_index: Optional[Union[int, list, dict]] = None,
         **plot_kwargs,
     ):
         """
@@ -279,6 +280,19 @@ class FermiSurfacePlotter:
                 combination with the ``vector_properties`` option.
             hide_labels: Whether to show the high-symmetry k-point labels.
             hide_cell: Whether to show the reciprocal cell boundary.
+            plot_index: A choice of band indices (0-based). Valid options are:
+
+                - A single integer, which will select that band index in both spin
+                  channels (if both spin channels are present).
+                - A list of integers, which will select that set of bands from both spin
+                  channels (if both a present).
+                - A dictionary of ``{Spin.up: band_index_1, Spin.down: band_index_2}``,
+                  where band_index_1 and band_index_2 are either single integers (if one
+                  wishes to plot a single band for that particular spin) or a list of
+                  integers. Note that the choice of integer and list can be different
+                  for different spin channels.
+                - ``None`` in which case all bands will be plotted.
+
             **plot_kwargs: Other keyword arguments supported by the individual plotting
                 methods.
         """
@@ -297,6 +311,7 @@ class FermiSurfacePlotter:
             hide_surface=hide_surface,
             hide_labels=hide_labels,
             hide_cell=hide_cell,
+            plot_index=plot_index,
         )
         if plot_type == "matplotlib":
             plot = self._get_matplotlib_plot(plot_data, **plot_kwargs)
@@ -308,7 +323,7 @@ class FermiSurfacePlotter:
             plot = self._get_crystal_toolkit_plot(plot_data, **plot_kwargs)
         else:
             types = ["matplotlib", "plotly", "mayavi", "crystal_toolkit"]
-            error_msg = "Plot type not recognised, valid options: {}".format(types)
+            error_msg = f"Plot type not recognised, valid options: {types}"
             raise ValueError(error_msg)
         return plot
 
@@ -328,6 +343,7 @@ class FermiSurfacePlotter:
         hide_surface: bool = False,
         hide_labels: bool = False,
         hide_cell: bool = False,
+        plot_index: List[int] = None,
     ) -> _FermiSurfacePlotData:
         """
         Get the the Fermi surface plot data.
@@ -346,7 +362,9 @@ class FermiSurfacePlotter:
 
         isosurfaces = []
         if not hide_surface:
-            isosurfaces = self.fermi_surface.all_vertices_faces(spins=spin)
+            isosurfaces = self.fermi_surface.all_vertices_faces(
+                spins=spin, band_index=plot_index
+            )
 
         properties = []
         properties_colormap = None
@@ -357,7 +375,10 @@ class FermiSurfacePlotter:
             # if the colormap used is different)
             norm = self.fermi_surface.properties_ndim == 2
             properties = self.fermi_surface.all_properties(
-                spins=spin, projection_axis=projection_axis, norm=norm
+                spins=spin,
+                band_index=plot_index,
+                projection_axis=projection_axis,
+                norm=norm,
             )
             if isinstance(color_properties, str):
                 properties_colormap = get_cmap(color_properties)
@@ -482,7 +503,7 @@ class FermiSurfacePlotter:
                 _mpl_sym_pt_style.update(sym_pt_kwargs)
                 _mpl_sym_label_style.update(sym_label_kwargs)
                 ax.scatter(*coords, **_mpl_sym_pt_style)
-                ax.text(*coords, "${}$".format(label), **_mpl_sym_label_style)
+                ax.text(*coords, f"${label}$", **_mpl_sym_label_style)
 
         xlim, ylim, zlim = np.linalg.norm(self.rlat, axis=1) / 2
         ax.set(xlim=(-xlim, xlim), ylim=(-ylim, ylim), zlim=(-zlim, zlim))
@@ -562,6 +583,7 @@ class FermiSurfacePlotter:
                     colorbar=_plotly_cbar_style,
                 )
                 meshes.append(trace)
+
         else:
             for c, (verts, faces) in zip(plot_data.colors, plot_data.isosurfaces):
                 c = rgb_to_plotly(c)
@@ -597,10 +619,10 @@ class FermiSurfacePlotter:
         scene = _plotly_scene.copy()
         if not plot_data.hide_labels:
             # plot high symmetry k-point markers
-            labels = ["${}$".format(i) for i in self._symmetry_pts[1]]
+            labels = [f"${i}$" for i in self._symmetry_pts[1]]
             x, y, z = self._symmetry_pts[0].T
             _plotly_sym_pt_style.update(sym_pt_kwargs)
-            trace = go.Scatter3d(x=x, y=y, z=z, mode="markers", **_plotly_bz_style)
+            trace = go.Scatter3d(x=x, y=y, z=z, mode="markers", **_plotly_sym_pt_style)
             meshes.append(trace)
 
             # add high symmetry label
@@ -693,7 +715,7 @@ class FermiSurfacePlotter:
 
         if not plot_data.hide_labels:
             # latexify labels
-            labels = ["${}$".format(i) for i in self._symmetry_pts[1]]
+            labels = [f"${i}$" for i in self._symmetry_pts[1]]
             for coords, label in zip(self._symmetry_pts[0], labels):
                 mlabtex(*coords, label, **_mayavi_sym_label_style)
 
@@ -712,7 +734,7 @@ class FermiSurfacePlotter:
     )
     def _get_crystal_toolkit_plot(
         self, plot_data: _FermiSurfacePlotData, opacity: float = 1.0
-    ) -> "Scene":
+    ):
         """
         Get a crystal toolkit Scene showing the Fermi surface.
 
@@ -850,6 +872,7 @@ class FermiSlicePlotter:
         hide_slice: bool = False,
         hide_labels: bool = False,
         hide_cell: bool = False,
+        plot_index: List[int] = None,
         arrow_pivot: str = "tail",
         slice_kwargs: Optional[Dict[str, Any]] = None,
         cbar_kwargs: Optional[Dict[str, Any]] = None,
@@ -924,6 +947,19 @@ class FermiSlicePlotter:
                 combination with the ``vector_properties`` option.
             hide_labels: Whether to show the high-symmetry k-point labels.
             hide_cell: Whether to show the reciprocal cell boundary.
+            plot_index: A choice of band indices (0-based). Valid options are:
+
+                - A single integer, which will select that band index in both spin
+                  channels (if both spin channels are present).
+                - A list of integers, which will select that set of bands from both spin
+                  channels (if both a present).
+                - A dictionary of ``{Spin.up: band_index_1, Spin.down: band_index_2}``,
+                  where band_index_1 and band_index_2 are either single integers (if one
+                  wishes to plot a single band for that particular spin) or a list of
+                  integers. Note that the choice of integer and list can be different
+                  for different spin channels.
+                - ``None`` in which case all bands will be plotted.
+
             arrow_pivot: The part of the arrow that is anchored to the X, Y grid.
                 The arrow rotates about this point, options are: tail, middle, tip.
             slice_kwargs: Optional arguments that are passed to ``LineCollection`` and
@@ -965,6 +1001,7 @@ class FermiSlicePlotter:
             hide_slice=hide_slice,
             hide_labels=hide_labels,
             hide_cell=hide_cell,
+            plot_index=plot_index,
         )
 
         if ax is None:
@@ -1031,7 +1068,7 @@ class FermiSlicePlotter:
                 ax.scatter(*coords, **_mpl_sym_pt_style)
                 ax.text(
                     *coords,
-                    "${}$".format(label),
+                    f"${label}$",
                     **_mpl_sym_label_style,
                     transform=ax.transData + offset,
                 )
@@ -1070,6 +1107,7 @@ class FermiSlicePlotter:
         hide_slice: bool = False,
         hide_labels: bool = False,
         hide_cell: bool = False,
+        plot_index: List[int] = None,
     ) -> _FermiSlicePlotData:
         """
         Get the the Fermi slice plot data.
@@ -1088,7 +1126,7 @@ class FermiSlicePlotter:
 
         slices = []
         if not hide_slice:
-            slices = self.fermi_slice.all_lines(spins=spin)
+            slices = self.fermi_slice.all_lines(spins=spin, band_index=plot_index)
 
         properties = []
         properties_colormap = None
@@ -1099,7 +1137,10 @@ class FermiSlicePlotter:
             # if the colormap used is different)
             norm = self.fermi_slice.properties_ndim == 2
             properties = self.fermi_slice.all_properties(
-                spins=spin, projection_axis=projection_axis, norm=norm
+                spins=spin,
+                band_index=plot_index,
+                projection_axis=projection_axis,
+                norm=norm,
             )
             if isinstance(color_properties, str):
                 properties_colormap = get_cmap(color_properties)
