@@ -165,13 +165,27 @@ class FermiSlice(MSONable):
         return max(ndims)
 
     def all_lines(
-        self, spins: Optional[Union[Spin, Collection[Spin]]] = None
+        self,
+        spins: Optional[Union[Spin, Collection[Spin]]] = None,
+        band_index: Optional[Union[int, list, dict]] = None,
     ) -> List[np.ndarray]:
         """
         Get the segments for all isolines.
 
         Args:
             spins: One or more spin channels to select. Default is all spins available.
+            band_index: A choice of band indices (0-based). Valid options are:
+
+                - A single integer, which will select that band index in both spin
+                  channels (if both spin channels are present).
+                - A list of integers, which will select that set of bands from both spin
+                  channels (if both a present).
+                - A dictionary of ``{Spin.up: band_index_1, Spin.down: band_index_2}``,
+                  where band_index_1 and band_index_2 are either single integers (if one
+                  wishes to plot a single band for that particular spin) or a list of
+                  integers. Note that the choice of integer and list can be different
+                  for different spin channels.
+                - ``None`` in which case all bands will be selected.
 
         Returns:
             A list of segments arrays.
@@ -181,11 +195,29 @@ class FermiSlice(MSONable):
         elif isinstance(spins, Spin):
             spins = [spins]
 
-        return [line.segments for spin in spins for line in self.isolines[spin]]
+        lines = []
+        if band_index is None:
+            band_index = {
+                spin: [i.band_idx for i in isolines]
+                for spin, isolines in self.isolines.items()
+            }
+        if not isinstance(band_index, dict):
+            band_index = {spin: band_index for spin in spins}
+        for spin, spin_index in band_index.items():
+            if isinstance(spin_index, int):
+                band_index[spin] = [spin_index]
+
+        for spin in spins:
+            for isoline in self.isolines[spin]:
+                if spin in band_index and isoline.band_idx in band_index[spin]:
+                    lines.append(isoline.segments)
+
+        return lines
 
     def all_properties(
         self,
         spins: Optional[Union[Spin, Collection[Spin]]] = None,
+        band_index: Optional[Union[int, list, dict]] = None,
         projection_axis: Optional[Tuple[int, int, int]] = None,
         norm: bool = False,
     ) -> List[np.ndarray]:
@@ -194,6 +226,18 @@ class FermiSlice(MSONable):
 
         Args:
             spins: One or more spin channels to select. Default is all spins available.
+            band_index: A choice of band indices (0-based). Valid options are:
+
+                - A single integer, which will select that band index in both spin
+                  channels (if both spin channels are present).
+                - A list of integers, which will select that set of bands from both spin
+                  channels (if both a present).
+                - A dictionary of ``{Spin.up: band_index_1, Spin.down: band_index_2}``,
+                  where band_index_1 and band_index_2 are either single integers (if one
+                  wishes to plot a single band for that particular spin) or a list of
+                  integers. Note that the choice of integer and list can be different
+                  for different spin channels.
+                - ``None`` in which case all bands will be selected.
             projection_axis: A (3, ) in array of the axis to project the properties onto
                 (vector properties only).
             norm: Calculate the norm of the properties (vector properties only).
@@ -208,21 +252,34 @@ class FermiSlice(MSONable):
             spins = [spins]
 
         projections = []
+
+        if band_index is None:
+            band_index = {
+                spin: [i.band_idx for i in isolines]
+                for spin, isolines in self.isolines.items()
+            }
+        if not isinstance(band_index, dict):
+            band_index = {spin: band_index for spin in spins}
+        for spin, spin_index in band_index.items():
+            if isinstance(spin_index, int):
+                band_index[spin] = [spin_index]
+
         for spin in spins:
-            for isosurface in self.isolines[spin]:
-                if projection_axis is not None:
-                    projections.append(isosurface.scalar_projection(projection_axis))
-                elif norm:
-                    projections.append(isosurface.properties_norms)
-                else:
-                    projections.append(isosurface.properties)
+            for isoline in self.isolines[spin]:
+                if spin in band_index and isoline.band_idx in band_index[spin]:
+                    if projection_axis is not None:
+                        projections.append(isoline.scalar_projection(projection_axis))
+                    elif norm:
+                        projections.append(isoline.properties_norms)
+                    else:
+                        projections.append(isoline.properties)
 
         return projections
 
     @classmethod
     def from_fermi_surface(
         cls,
-        fermi_surface: "FermiSurface",
+        fermi_surface,
         plane_normal: Tuple[int, int, int],
         distance: float = 0,
     ) -> "FermiSlice":
