@@ -298,13 +298,27 @@ class FermiSurface(MSONable):
         return tuple(self.isosurfaces.keys())
 
     def all_vertices_faces(
-        self, spins: Optional[Union[Spin, Collection[Spin]]] = None
+        self,
+        spins: Optional[Union[Spin, Collection[Spin]]] = None,
+        band_index: Optional[Union[int, list, dict]] = None,
     ) -> List[Tuple[np.ndarray, np.ndarray]]:
         """
         Get the vertices and faces for all isosurfaces.
 
         Args:
             spins: One or more spin channels to select. Default is all spins available.
+            band_index: A choice of band indices (0-based). Valid options are:
+
+                - A single integer, which will select that band index in both spin
+                  channels (if both spin channels are present).
+                - A list of integers, which will select that set of bands from both spin
+                  channels (if both a present).
+                - A dictionary of ``{Spin.up: band_index_1, Spin.down: band_index_2}``,
+                  where band_index_1 and band_index_2 are either single integers (if one
+                  wishes to plot a single band for that particular spin) or a list of
+                  integers. Note that the choice of integer and list can be different
+                  for different spin channels.
+                - ``None`` in which case all bands will be selected.
 
         Returns:
             A list of (vertices, faces).
@@ -315,15 +329,28 @@ class FermiSurface(MSONable):
             spins = [spins]
 
         vertices_faces = []
+        if band_index is None:
+            band_index = {
+                spin: [i.band_idx for i in isosurfaces]
+                for spin, isosurfaces in self.isosurfaces.items()
+            }
+        if not isinstance(band_index, dict):
+            band_index = {spin: band_index for spin in spins}
+        for spin, spin_index in band_index.items():
+            if isinstance(spin_index, int):
+                band_index[spin] = [spin_index]
+
         for spin in spins:
             for isosurface in self.isosurfaces[spin]:
-                vertices_faces.append((isosurface.vertices, isosurface.faces))
+                if spin in band_index and isosurface.band_idx in band_index[spin]:
+                    vertices_faces.append((isosurface.vertices, isosurface.faces))
 
         return vertices_faces
 
     def all_properties(
         self,
         spins: Optional[Union[Spin, Collection[Spin]]] = None,
+        band_index: Optional[Union[int, list, dict]] = None,
         projection_axis: Optional[Tuple[int, int, int]] = None,
         norm: bool = False,
     ) -> List[np.ndarray]:
@@ -332,6 +359,19 @@ class FermiSurface(MSONable):
 
         Args:
             spins: One or more spin channels to select. Default is all spins available.
+            band_index: A choice of band indices (0-based). Valid options are:
+
+                - A single integer, which will select that band index in both spin
+                  channels (if both spin channels are present).
+                - A list of integers, which will select that set of bands from both spin
+                  channels (if both a present).
+                - A dictionary of ``{Spin.up: band_index_1, Spin.down: band_index_2}``,
+                  where band_index_1 and band_index_2 are either single integers (if one
+                  wishes to plot a single band for that particular spin) or a list of
+                  integers. Note that the choice of integer and list can be different
+                  for different spin channels.
+                - ``None`` in which case all bands will be selected.
+
             projection_axis: A (3, ) in array of the axis to project the properties onto
                 (vector properties only).
             norm: Calculate the norm of the properties (vector properties only).
@@ -346,14 +386,29 @@ class FermiSurface(MSONable):
             spins = [spins]
 
         projections = []
+
+        if band_index is None:
+            band_index = {
+                spin: [i.band_idx for i in isosurfaces]
+                for spin, isosurfaces in self.isosurfaces.items()
+            }
+        if not isinstance(band_index, dict):
+            band_index = {spin: band_index for spin in spins}
+        for spin, spin_index in band_index.items():
+            if isinstance(spin_index, int):
+                band_index[spin] = [spin_index]
+
         for spin in spins:
             for isosurface in self.isosurfaces[spin]:
-                if projection_axis is not None:
-                    projections.append(isosurface.scalar_projection(projection_axis))
-                elif norm:
-                    projections.append(isosurface.properties_norms)
-                else:
-                    projections.append(isosurface.properties)
+                if spin in band_index and isosurface.band_idx in band_index[spin]:
+                    if projection_axis is not None:
+                        projections.append(
+                            isosurface.scalar_projection(projection_axis)
+                        )
+                    elif norm:
+                        projections.append(isosurface.properties_norms)
+                    else:
+                        projections.append(isosurface.properties)
 
         return projections
 
@@ -455,9 +510,7 @@ class FermiSurface(MSONable):
 
         return cls(isosurfaces, reciprocal_space, structure)
 
-    def get_fermi_slice(
-        self, plane_normal: Tuple[int, int, int], distance: float = 0
-    ) -> "FermiSlice":
+    def get_fermi_slice(self, plane_normal: Tuple[int, int, int], distance: float = 0):
         """
         Get a slice through the Fermi surface.
 
